@@ -33,7 +33,7 @@ Forest::Forest() :
         true), memory_saving_splitting(false), splitrule(DEFAULT_SPLITRULE), predict_all(false), keep_inbag(false), sample_fraction(
         { 1 }), holdout(false), prediction_type(DEFAULT_PREDICTIONTYPE), num_random_splits(DEFAULT_NUM_RANDOM_SPLITS), max_depth(
         DEFAULT_MAXDEPTH), nsplits(0), npairs(0), proptry(0.0), alpha(DEFAULT_ALPHA), minprop(DEFAULT_MINPROP), num_threads(DEFAULT_NUM_THREADS), data { }, overall_prediction_error(
-    NAN), importance_mode(DEFAULT_IMPORTANCE_MODE), progress(0) {  // asdf
+    NAN), importance_mode(DEFAULT_IMPORTANCE_MODE), progress(0) { 
 }
 
 void Forest::initR(std::string dependent_variable_name, std::unique_ptr<Data> input_data, uint mtry, uint num_trees,
@@ -43,7 +43,7 @@ void Forest::initR(std::string dependent_variable_name, std::unique_ptr<Data> in
     const std::vector<std::string>& unordered_variable_names, bool memory_saving_splitting, SplitRule splitrule,
     std::vector<double>& case_weights, std::vector<std::vector<size_t>>& manual_inbag, bool predict_all,
     bool keep_inbag, std::vector<double>& sample_fraction, uint nsplits, uint npairs, double proptry, double alpha, double minprop, bool holdout,
-    PredictionType prediction_type, uint num_random_splits, bool order_snps, uint max_depth, std::vector<std::vector<size_t>>& promispairs, uint& eim_mode, uint& divfortype, std::vector<size_t>& metricind) {
+    PredictionType prediction_type, uint num_random_splits, bool order_snps, uint max_depth, std::vector<std::vector<size_t>>& promispairs, uint& eim_mode, uint& divfortype) {
 
   this->verbose_out = verbose_out;
 
@@ -51,7 +51,7 @@ void Forest::initR(std::string dependent_variable_name, std::unique_ptr<Data> in
   init(dependent_variable_name, MEM_DOUBLE, std::move(input_data), mtry, "", num_trees, seed, num_threads,
       importance_mode, min_node_size, status_variable_name, prediction_mode, sample_with_replacement,
       unordered_variable_names, memory_saving_splitting, splitrule, predict_all, sample_fraction, nsplits, npairs, proptry, alpha, minprop,
-      holdout, prediction_type, num_random_splits, order_snps, max_depth, promispairs, eim_mode, divfortype, metricind);
+      holdout, prediction_type, num_random_splits, order_snps, max_depth, promispairs, eim_mode, divfortype);
 
   // Set variables to be always considered for splitting
   if (!always_split_variable_names.empty()) {
@@ -85,7 +85,7 @@ void Forest::init(std::string dependent_variable_name, MemoryMode memory_mode, s
     uint min_node_size, std::string status_variable_name, bool prediction_mode, bool sample_with_replacement,
     const std::vector<std::string>& unordered_variable_names, bool memory_saving_splitting, SplitRule splitrule,
     bool predict_all, std::vector<double>& sample_fraction, uint nsplits, uint npairs, double proptry, double alpha, double minprop, bool holdout,
-    PredictionType prediction_type, uint num_random_splits, bool order_snps, uint max_depth, std::vector<std::vector<size_t>>& promispairs, uint eim_mode, uint divfortype, std::vector<size_t>& metricind) {
+    PredictionType prediction_type, uint num_random_splits, bool order_snps, uint max_depth, std::vector<std::vector<size_t>>& promispairs, uint eim_mode, uint divfortype) {
 
   // Initialize data with memmode
   this->data = std::move(input_data);
@@ -125,13 +125,12 @@ void Forest::init(std::string dependent_variable_name, MemoryMode memory_mode, s
   this->prediction_type = prediction_type;
   this->num_random_splits = num_random_splits;
   this->max_depth = max_depth;
-  this->nsplits = nsplits; // asdf
-  this->npairs = npairs; // asdf
-  this->proptry = proptry; // asdf
+  this->nsplits = nsplits;
+  this->npairs = npairs;
+  this->proptry = proptry;
   this->promispairs = promispairs;
   this->eim_mode = eim_mode;
   this->divfortype = divfortype;
-  this->metricind = metricind;
   
   // Set number of samples and variables
   num_samples = data->getNumRows();
@@ -202,7 +201,7 @@ void Forest::run(bool verbose, bool compute_oob_error) {
       computePredictionError();
     }
 
-    if (importance_mode == IMP_PERM_BREIMAN || importance_mode == IMP_PERM_LIAW || importance_mode == IMP_PERM_RAW || importance_mode == MUWIMP_BOTH || importance_mode == MUWIMP_MULTIWAY || importance_mode == MUWIMP_DISCR) {
+    if (importance_mode == IMP_PERM_BREIMAN || importance_mode == IMP_PERM_LIAW || importance_mode == IMP_PERM_RAW || importance_mode == MUWIMP_BOTH || importance_mode == MUWIMP_CLASSFOC || importance_mode == MUWIMP_DISCR) {
       if (verbose && verbose_out) {
         *verbose_out << "Computing permutation variable importance .." << std::endl;
       }
@@ -290,7 +289,7 @@ void Forest::grow() {
     trees[i]->init(data.get(), mtry, nsplits, npairs, proptry, dependent_varID, num_samples, tree_seed, &deterministic_varIDs,
         &split_select_varIDs, tree_split_select_weights, importance_mode, min_node_size, sample_with_replacement,
         memory_saving_splitting, splitrule, &case_weights, tree_manual_inbag, keep_inbag, &sample_fraction, alpha,
-        minprop, holdout, num_random_splits, max_depth, &promispairs, eim_mode, divfortype, &metricind);
+        minprop, holdout, num_random_splits, max_depth, &promispairs, eim_mode, divfortype);
   }
 
 // Init variable importance
@@ -721,6 +720,7 @@ void Forest::predictInternalInThread(uint thread_idx) {
       condition_variable.notify_one();
     }
   }
+
 }
 
 void Forest::computeTreePermutationImportanceInThread(uint thread_idx, std::vector<double>& importance,
